import React, { useState, useEffect } from 'react';
import Table from 'react-bootstrap/Table';

function Header(_ref) {
  var header = _ref.header,
      sortState = _ref.sortState,
      setSortState = _ref.setSortState;
  var columnsHeader = header.map(function (item, index) {
    return React.createElement("th", {
      style: {
        width: item.width ? item.width : "",
        cursor: item.sortable ? "pointer" : "default"
      },
      key: index,
      onClick: function onClick() {
        if (item.sortable) {
          setSortState({
            sortField: item.field,
            sortAsc: sortState.sortField === item.field ? !sortState.sortAsc : true
          }); // inverse sortAsc, only when sortField has not changed, otherwise sortAsc=true
        }
      }
    }, // for current sorted column draws icon
    (sortState == null ? void 0 : sortState.sortField) === item.field ? React.createElement(React.Fragment, null, React.createElement("div", {
      style: {
        "float": "left",
        textAlign: "left"
      }
    }, item.headerName), React.createElement("div", {
      style: {
        "float": "right",
        textAlign: "right"
      }
    }, React.createElement("span", {
      style: {
        fontSize: "8pt",
        color: "gray"
      }
    }, " ", sortState.sortAsc ? "▼" : "▲"))) : item.headerName);
  });
  return React.createElement(React.Fragment, null, columnsHeader);
}

function DataRow(_ref) {
  var columns = _ref.columns,
      row = _ref.row,
      indexRow = _ref.indexRow,
      OnClickButtons = _ref.OnClickButtons;

  var getUniqKey = function getUniqKey(row, index) {
    return String(row.id) + "." + String(index);
  };

  var result = columns.map(function (col, index) {
    if (typeof row[col.field] !== "object") {
      //if it's not object, then it's just value of field, else it's array of buttons
      if (col != null && col.dateTimeOption) {
        if (col.dateTimeOption === "onlyDate") {
          return React.createElement("td", {
            key: getUniqKey(row, index)
          }, new Date(row[col.field]).toLocaleDateString());
        }

        if (col.dateTimeOption === "onlyTime") {
          return React.createElement("td", {
            key: getUniqKey(row, index)
          }, new Date(row[col.field]).toLocaleTimeString());
        }

        if (col.dateTimeOption === "dateTime") {
          var dateTime = new Date(row[col.field]).toLocaleDateString() + " " + new Date(row[col.field]).toLocaleTimeString();
          return React.createElement("td", {
            key: getUniqKey(row, index)
          }, dateTime);
        }

        return React.createElement("td", {
          key: getUniqKey(row, index)
        }, row[col.field]);
      }

      if (col.field === "#") {
        return React.createElement("td", {
          key: getUniqKey(row, index)
        }, indexRow + 1);
      }

      return React.createElement("td", {
        key: getUniqKey(row, index)
      }, row[col.field]);
    } // buttons


    var buttons = row[col.field];

    if (Array.isArray(buttons)) {
      var buttonRow = [];
      buttons.forEach(function (button) {
        if ((button != null && button.text || button != null && button.iconFA) && button != null && button.idButton) {
          var buttonText = [];

          if (button != null && button.iconFA) {
            if (button != null && button.iconFASize) {
              buttonText.push(React.createElement("i", {
                key: getUniqKey(row, index) + button.idButton,
                className: button.iconFA,
                style: {
                  fontSize: button.iconFASize
                }
              }));
            } else {
              buttonText.push(React.createElement("i", {
                key: getUniqKey(row, index) + button.idButton,
                className: button.iconFA
              }));
            }
          }

          if (button != null && button.text) {
            buttonText.push(React.createElement("span", {
              key: getUniqKey(row, index) + button.idButton
            }, button.text));
          }

          if (OnClickButtons) {
            buttonRow.push(React.createElement("span", {
              key: getUniqKey(row, index) + button.idButton
            }, React.createElement("a", {
              href: "#",
              onClick: function onClick() {
                return OnClickButtons(row, button.idButton);
              }
            }, buttonText), " "));
          } else {
            buttonRow.push(React.createElement("span", {
              key: getUniqKey(row, index) + button.idButton
            }, buttonText));
          }
        }
      });
      return React.createElement("td", {
        key: getUniqKey(row, index)
      }, buttonRow);
    }

    return React.createElement("td", {
      key: getUniqKey(row, index)
    }, row[col.field]);
  });
  return result;
}

function TableData(_ref) {
  var data = _ref.data,
      sortState = _ref.sortState,
      columns = _ref.columns,
      noDataTitle = _ref.noDataTitle,
      OnClickButtons = _ref.OnClickButtons;

  function compare(a, b) {
    //@ts-ignore
    if (a[sortState.sortField] < b[sortState.sortField]) {
      if (sortState.sortAsc) {
        return -1;
      } else {
        return 1;
      }
    } //@ts-ignore


    if (a[sortState.sortField] > b[sortState.sortField]) {
      if (sortState.sortAsc) {
        return 1;
      } else {
        return -1;
      }
    }

    return 0;
  } // sorting of data


  var sortedData = [];

  if (sortState.sortField && data) {
    sortedData = data.sort(compare); //sortedData = dataTable?.sort(compare);
  } else {
    sortedData = data;
  } // fill out


  if (sortedData && sortedData.length > 0) {
    return React.createElement(React.Fragment, null, sortedData.map(function (row, index) {
      return React.createElement("tr", {
        key: row.id
      }, React.createElement(DataRow, {
        columns: columns,
        row: row,
        indexRow: index,
        OnClickButtons: OnClickButtons
      }));
    }));
  }

  return React.createElement("tr", null, React.createElement("td", {
    style: {
      textAlign: "center"
    },
    colSpan: columns.length
  }, noDataTitle));
}

function BootstrapTable(_ref) {
  var columns = _ref.columns,
      data = _ref.data,
      sortField = _ref.sortField,
      _ref$sortAsc = _ref.sortAsc,
      sortAsc = _ref$sortAsc === void 0 ? true : _ref$sortAsc,
      size = _ref.size,
      variant = _ref.variant,
      OnClickButtons = _ref.OnClickButtons,
      _ref$noDataTitle = _ref.noDataTitle,
      noDataTitle = _ref$noDataTitle === void 0 ? 'no data' : _ref$noDataTitle;

  var _useState = useState({
    sortField: sortField,
    sortAsc: sortAsc
  }),
      sortState = _useState[0],
      setSortState = _useState[1];

  var _useState2 = useState(data),
      dataTable = _useState2[0],
      setDataTable = _useState2[1];

  useEffect(function () {
    setDataTable(data);
  }, [data]);
  return React.createElement(Table, {
    striped: true,
    bordered: true,
    hover: true,
    size: size,
    variant: variant
  }, React.createElement("thead", null, React.createElement("tr", null, React.createElement(Header, {
    header: columns,
    sortState: sortState,
    setSortState: setSortState
  }))), React.createElement("tbody", null, React.createElement(TableData, {
    columns: columns,
    data: dataTable,
    sortState: sortState,
    noDataTitle: noDataTitle,
    OnClickButtons: OnClickButtons
  })));
}

export { BootstrapTable };
//# sourceMappingURL=react-bootstrap-table-light.esm.js.map
